==> libevnet-0.2.tgz: libevnet-0.2/src/socket.h <==
/* ==========================================================================
 * libevnet/src/socket.h - Network server library for libevent.
 * --------------------------------------------------------------------------
 * Copyright (c) 2006  William Ahern
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the
 * following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 * ==========================================================================
 */
#ifndef EVNET_SOCKET_H
#define EVNET_SOCKET_H

#include <string.h>	/* strerror(3) */

#include <sys/types.h>	/* mode_t socklen_t */
#include <sys/socket.h>	/* struct sockaddr struct sockaddr_storage */
#include <sys/un.h>	/* struct sockaddr_un */

#include <netinet/in.h>	/* struct sockaddr_in struct sockaddr_in6 */


struct event_base;
struct arena_prototype;


#define SOCKET_SA_P(s)	((struct sockaddr *)(s))

#define SOCKET_SA_LENOF(s)	\
	( (SOCKET_SA_P(s)->sa_family == AF_INET)  ? sizeof(struct sockaddr_in)	\
	: (SOCKET_SA_P(s)->sa_family == AF_INET6) ? sizeof(struct sockaddr_in6)	\
	: (SOCKET_SA_P(s)->sa_family == AF_UNIX)  ? sizeof(struct sockaddr_un)	\
	: 0 )

#define SOCKET_UN_P(s)	((struct sockaddr_un *)(s))

#define SOCKET_STRERROR(e)	\
	(((e) == SOCKET_ESYSTEM)? strerror(errno) : socket_errlist[(e)])

enum socket_errno {
	SOCKET_ESUCCESS,
	SOCKET_ESYSTEM,
	SOCKET_ETIMEDOUT,
	SOCKET_ECANCELLED,
	SOCKET_ENOTFOUND,
}; /* enum socket_errno */

extern const char *socket_errlist[];

extern const int socket_nerr;


struct socket_name {
	void *type;

	union {
		struct sockaddr sa;
		struct sockaddr_storage ss;

		struct sockaddr_in sin;
		struct sockaddr_in6 sin6;
		struct sockaddr_un sun;
	} addr;

	struct {
		char name[256];

		char port[32];	/* More than enough for +/-2^64 in decimal. */
	} host;

	struct {
		char path[sizeof ((struct sockaddr_un *)0)->sun_path];
	} local;
}; /* struct socket_name */

extern const struct socket_options {
	int cb_onclose;

	mode_t sun_mask;

	int sun_unlink;

	int sa_reuseaddr;

	int so_type;

	int so_nonblock;

	int so_backlog;
} socket_defaults;


struct socket_service;

struct socket_accept;

struct socket_connect;


struct socket_service *socket_open(const struct socket_options *, struct event_base *, const struct arena_prototype *);

void socket_close(struct socket_service *);

typedef void (*socket_accept_cb)(int fd, struct sockaddr *, socklen_t, enum socket_errno, void *);

enum socket_errno socket_accept(struct socket_accept **, struct socket_service *, struct socket_name *, socket_accept_cb, void *, struct timeval *);

enum socket_errno socket_errno(struct socket_service *);

const char *socket_strerror(struct socket_service *);


typedef void (*socket_connect_cb)(int, struct sockaddr *, socklen_t, enum socket_errno, void *);

void socket_connect(struct socket_connect **, struct socket_service *, struct socket_name *, socket_connect_cb, void *, struct timeval *);


struct socket_name *soname_set_addr(struct socket_name *dst, const struct sockaddr *src, socklen_t srclen);
struct socket_name *soname_set_host(struct socket_name *dst, const char *src, const char *port);
struct socket_name *soname_set_local(struct socket_name *dst, const char *src);

#endif /* EVNET_SOCKET_H */

==> libevnet-0.3.1.tgz: libevnet-0.3.1/src/socket.h <==
/* ==========================================================================
 * libevnet/src/socket.h - Network server library for libevent.
 * --------------------------------------------------------------------------
 * Copyright (c) 2006  William Ahern
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the
 * following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 * ==========================================================================
 */
#ifndef EVNET_SOCKET_H
#define EVNET_SOCKET_H

#include <string.h>	/* strerror(3) */

#include <sys/types.h>	/* mode_t socklen_t */
#include <sys/socket.h>	/* struct sockaddr struct sockaddr_storage */
#include <sys/un.h>	/* struct sockaddr_un */

#include <netinet/in.h>	/* struct sockaddr_in struct sockaddr_in6 */


struct event_base;
struct arena_prototype;
struct tls_context;


#define SOCKET_SA_P(s)	((struct sockaddr *)(s))

#define SOCKET_SA_LENOF(s)	\
	( (SOCKET_SA_P(s)->sa_family == AF_INET)  ? sizeof(struct sockaddr_in)	\
	: (SOCKET_SA_P(s)->sa_family == AF_INET6) ? sizeof(struct sockaddr_in6)	\
	: (SOCKET_SA_P(s)->sa_family == AF_UNIX)  ? sizeof(struct sockaddr_un)	\
	: 0 )

#define SOCKET_UN_P(s)	((struct sockaddr_un *)(s))

#define SOCKET_STRERROR(e)	\
	(((e) == SOCKET_ESYSTEM)? strerror(errno) : socket_errlist[(e)])

enum socket_errno {
	SOCKET_ESUCCESS,
	SOCKET_ESYSTEM,
	SOCKET_ETIMEDOUT,
	SOCKET_ECANCELLED,
	SOCKET_ENOTFOUND,
	SOCKET_ENOTLS,
}; /* enum socket_errno */

extern const char *socket_errlist[];

extern const int socket_nerr;


struct socket_name {
	void *type;

	union {
		struct sockaddr sa;
		struct sockaddr_storage ss;

		struct sockaddr_in sin;
		struct sockaddr_in6 sin6;
		struct sockaddr_un sun;
	} addr;

	struct {
		char name[256];

		char port[32];	/* More than enough for +/-2^64 in decimal. */
	} host;

	struct {
		char path[sizeof ((struct sockaddr_un *)0)->sun_path];
	} local;
}; /* struct socket_name */


struct connect_info {
	struct {
		union {
			struct sockaddr_in sin;
			struct sockaddr_in6 sin6;
			struct sockaddr_un sun;
			struct sockaddr_storage ss;
		} sa;

		socklen_t salen;
	} peer, self;

	struct tls *tls;
}; /* struct connect_info */


extern const struct socket_options {
	int cancel_onclose;
	int notify_onclose;

	mode_t sun_mask;

	int sun_unlink;

	int sa_reuseaddr;

	int so_type;

	int so_nonblock;

	int so_backlog;
} socket_defaults;


struct socket;

struct socket *socket_open(const struct socket_options *, struct event_base *, const struct arena_prototype *);

void socket_close(struct socket *);

void socket_tls_enable(struct socket *, struct tls_context *);

typedef void (*socket_accept_cb)(int fd, struct connect_info *, enum socket_errno, void *);

enum socket_errno socket_accept(struct socket *, struct socket_name *, socket_accept_cb, void *, struct timeval *);

enum socket_errno socket_errno(struct socket *);

const char *socket_strerror(struct socket *);

typedef void (*socket_connect_cb)(int, struct connect_info *, enum socket_errno, void *);

void socket_connect(struct socket *, struct socket_name *, socket_connect_cb, void *, struct timeval *);


struct socket_name *soname_set_addr(struct socket_name *dst, const struct sockaddr *src, socklen_t srclen);
struct socket_name *soname_set_host(struct socket_name *dst, const char *src, const char *port);
struct socket_name *soname_set_local(struct socket_name *dst, const char *src);

#endif /* EVNET_SOCKET_H */
